!$Header: /home/ssipsl/CVSREP/ORCHIDEE/src_parameters/constantes_co2.f90,v 1.10 2007/05/28 15:28:05 ssipsl Exp $
!IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!-
MODULE constantes_co2
!!--------------------------------------------------------------------
!! "constantes_co2" module contains some public technical constants
!!--------------------------------------------------------------------
  USE constantes_veg
!-
  IMPLICIT NONE
!-
! indices for assimilation parameters
!-
  INTEGER(i_std),PARAMETER :: itmin = 1
  INTEGER(i_std),PARAMETER :: itopt = 2
  INTEGER(i_std),PARAMETER :: itmax = 3
  INTEGER(i_std),PARAMETER :: ivcmax = 4
  INTEGER(i_std),PARAMETER :: ivjmax = 5
  INTEGER(i_std),PARAMETER :: npco2 = 5
!-
!!
!! The following tables of parameters for SECHIBA
!! are in the following order :
!!
!!    1 - Bare soil
!!    2 - tropical  broad-leaved evergreen
!!    3 - tropical  broad-leaved raingreen
!!    4 - temperate needleleaf   evergreen
!!    5 - temperate broad-leaved evergreen
!!    6 - temperate broad-leaved summergreen
!!    7 - boreal    needleleaf   evergreen
!!    8 - boreal    broad-leaved summergreen
!!    9 - boreal    needleleaf   summergreen
!!   10 -           C3           grass
!!   11 -           C4           grass
!!   12 -           C3           agriculture
!!   13 -           C4           agriculture
!!
! flag for C4 vegetation types
  LOGICAL,DIMENSION(nvm),SAVE :: &
 &  is_c4 = (/.false.,.false.,.false.,.false.,.false.,.false., &
 &            .false.,.false.,.false.,.false.,.true.,.false.,.true. /)
! Slope of the gs/A relation (Ball & al.)
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  gsslope = (/0., 9., 9., 9., 9., 9., 9., 9., 9., 9., 3., 9., 3./)
! intercept of the gs/A relation (Ball & al.)
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  gsoffset = (/0.0,  0.01, 0.01, 0.01, 0.01, 0.01, &
 &               0.01, 0.01, 0.01, 0.01, 0.03, 0.01, 0.03/)
! values used for vcmax when STOMATE is not activated
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  vcmax_fix = (/  0., 40., 50., 30., 35., 40., &
 &                 30., 40., 35., 60., 60., 70., 70. /)
! values used for vjmax when STOMATE is not activated
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  vjmax_fix = (/ 0., 80., 100., 60., 70., 80., &
 &                 60., 80., 70., 120., 120., 140., 140. /)
! values used for photosynthesis tmin when STOMATE is not activated
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  co2_tmin_fix = (/ 0.,  2.,  2., -4., -3., -2., &
 &                   -4., -4., -4., -5.,  6., -5.,  6. /)
! values used for photosynthesis topt when STOMATE is not activated
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  co2_topt_fix = (/  0.,  27.5, 27.5, 17.5, 25.,  20.,  &
 &                    17.5, 17.5, 17.5, 20.,  32.5, 20.,  32.5 /)
! values used for photosynthesis tmax when STOMATE is not activated
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  co2_tmax_fix = (/ 0., 55., 55., 38., 48., 38., &
 &                   38., 38., 38., 45., 55., 45., 55. /)
! extinction coefficient of the Monsi&Seaki relationship (1953)
  REAL(r_std),DIMENSION(nvm),SAVE :: &
 &  ext_coef = (/.5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5/)
! NV080800 Name of STOMATE forcing file
  CHARACTER(LEN=100) :: stomate_forcing_name='NONE'
! NV080800 Name of soil forcing file
  CHARACTER(LEN=100) :: stomate_Cforcing_name='NONE'
!-
  INTEGER(i_std),SAVE :: forcing_id
!------------------------
END MODULE constantes_co2
